<?xml version='1.0' encoding='iso-8859-1'?>
<xsl:stylesheet xmlns:xsl="http://www.w3.org/1999/XSL/Transform"
                version='1.0'>
  
  <!-- Node context: body -->
  <xsl:template name="maketoc.div.split">
    
    <xsl:message terminate="no">[maketoc.div.split] name=<xsl:value-of select="name()"/></xsl:message>
    
    <xsl:if test="$make.toc">
      <xsl:variable name="nodes" select="div"/>
      <xsl:if test="$nodes">
	<div class="div.toc">
	  <dl>
	    <xsl:apply-templates select="$nodes" mode="toc.split"/>
	  </dl>
	</div> 
      </xsl:if>
    </xsl:if>
  </xsl:template>
  
  
  <xsl:template match="div" mode="toc.split">
    <xsl:param name="div.depth"><xsl:call-template name="div.depth"/></xsl:param>
    <xsl:param name="div.id"><xsl:call-template name="element.id"/></xsl:param>
    
    <xsl:message terminate="no">[toc.split] depth=<xsl:value-of select="$div.depth"/> id=<xsl:value-of select="$div.id"/></xsl:message>
    
    <dt>
      <b><xsl:call-template name="i18n.text.type"/><xsl:call-template name="nbsp"/>
	<xsl:call-template name="head.xref.split">
	  <xsl:with-param name="content"><xsl:call-template name="div.header"/></xsl:with-param>
	  <xsl:with-param name="div.depth" select="$div.depth"/>
	  <xsl:with-param name="div.id" select="$div.id"/>
	</xsl:call-template></b>
    </dt>
    <xsl:if test="$toc.div.depth > 0 and div">
      <dd>
	<dl>
	  <xsl:apply-templates select="div" mode="toc.split"/>
	</dl>
      </dd>
    </xsl:if>
  </xsl:template>
  
  
  <!-- Contextual node: div -->
  <xsl:template name="head.xref.split">

    <xsl:param name="div.id" select="generate-id(.)"/>
    <xsl:param name="div.depth">0</xsl:param>
    <xsl:param name="content" select="head[1]"/>

    <xsl:choose>
      <xsl:when test="$div.depth &lt; $output.split.level">
	<xsl:variable name="file.name" select="concat($div.id, $output.html.extension)"/>
	<a><xsl:attribute name="href">
	    <xsl:value-of select="$file.name"/>
	  </xsl:attribute><xsl:value-of select="$content"/></a>
      </xsl:when>
      <xsl:otherwise>
	
	<xsl:variable name="parent.name"><xsl:apply-templates select="ancestor::div[last()]" mode="toc.split.parent"/></xsl:variable>
	
	<xsl:message>parent.name=<xsl:value-of select="$parent.name"/></xsl:message>

	<a><xsl:attribute name="href">
	    <xsl:value-of select="$parent.name"/><xsl:text>#</xsl:text>
	    <xsl:call-template name="element.id">
	      <xsl:with-param name="element" select="."/>
	    </xsl:call-template>
	  </xsl:attribute><xsl:value-of select="$content"/></a>
      </xsl:otherwise>
    </xsl:choose>

  </xsl:template>
  
  
  <xsl:template match="div" mode="toc.split.parent">
    <xsl:param name="div.depth"><xsl:call-template name="div.depth"/></xsl:param>
    <xsl:param name="div.id"><xsl:call-template name="element.id"/></xsl:param>
    
    <xsl:message terminate="no">[toc.split.parent] depth=<xsl:value-of select="$div.depth"/> id=<xsl:value-of select="$div.id"/></xsl:message>

    <xsl:choose>
      <xsl:when test="$div.depth &lt; $output.split.level">
	<xsl:value-of select="concat($div.id, $output.html.extension)"/>
      </xsl:when>
      <xsl:otherwise>
	<xsl:apply-templates select="ancestor::div" mode="toc.split.parent">
	  <xsl:with-param name="div.depth" select="$div.depth"/>
	</xsl:apply-templates>
      </xsl:otherwise>
    </xsl:choose>
    
  </xsl:template>
  
</xsl:stylesheet>

<!-- Keep this comment at the end of the file
Local variables:
mode: xml
sgml-always-quote-attributes:t
sgml-indent-step:2
sgml-indent-data:t
sgml-default-dtd-file:"/local/led/share/dtd/xsl/xsl.ced"
End:
-->
